@@ -9,7 +9,7 @@
 #
 package CatalystX::Controller::ExtJS::REST;
 BEGIN {
-  $CatalystX::Controller::ExtJS::REST::VERSION = '1.101700';
+  $CatalystX::Controller::ExtJS::REST::VERSION = '1.110000';
 }
 # ABSTRACT: RESTful interface to dbic objects
 
@@ -132,7 +132,8 @@ sub _build_form_base_path {
 sub _build_form_base_file {
     my $self = shift;
     my @path = split( /\//, $self->action_namespace );
-    return $self->form_base_path->file((pop @path) . '.yml');
+    my $file = pop @path;
+    return $self->form_base_path->subdir(@path)->file($file . '.yml');
 }
 
 sub _build_list_base_path {
@@ -539,7 +540,7 @@ CatalystX::Controller::ExtJS::REST - RESTful interface to dbic objects
 
 =head1 VERSION
 
-version 1.101700
+version 1.110000
 
 =head1 SYNOPSIS
 
